@@ -92,7 +92,7 @@ fn parse_commit(message: &str) -> Option<Commit> {
                     0 => long_sha = Some(line),
                     1 => email = Some(line.to_string()),
                     2 => subject = Some(line),
-                    _ => message_lines.push(line),
+                    _ => message_lines.push(line.to_string()),
                 }
             }
         }
@@ -138,55 +138,76 @@ pub fn parse_commit_hook_format(
     has_changes: bool,
 ) -> Commit {
     let mut subject = None;
-    let mut message_lines = Vec::<&str>::new();
+    let mut message_lines = vec![];
     let scissor_line = format!("{} {}", comment_char, SCISSORS);
     debug!("Using clean up mode: {:?}", cleanup_mode);
     debug!("Using config core.commentChar: {:?}", comment_char);
-    for (index, mut line) in message.lines().enumerate() {
-        match index {
-            0 => subject = Some(line),
-            _ => {
-                match cleanup_mode {
-                    CleanupMode::Scissors => {
-                        if line == scissor_line {
-                            debug!("Found scissors line. Stop parsing message.");
-                            break;
-                        }
-                    }
-                    CleanupMode::Default | CleanupMode::Strip => {
-                        line = line.trim_end();
-                        if line.starts_with(&comment_char) {
-                            continue;
-                        }
-                    }
-                    CleanupMode::Verbatim => {}
-                    CleanupMode::Whitespace => {
-                        line = line.trim_end();
-                    }
+    for line in message.lines() {
+        // A scissor line has been detected.
+        //
+        // A couple reasons why this could happen:
+        //
+        // - A scissor line was found in cleanup mode "scissors". All content after this line is
+        //   ignored.
+        // - A scissor line was found in a different cleanup mode with the `--verbose` option.
+        //   Lintje cannot detect this verbose mode so it assumes it's for the verbose mode
+        //   and ignores all content after this line.
+        // - The commit message is entirely empty, leaving only the comments added to the file by
+        //   Git. Unless `--allow-empty-message` is specified this is the user telling Git it stop
+        //   the commit process.
+        if line == scissor_line {
+            debug!("Found scissors line. Stop parsing message.");
+            break;
+        }
+
+        // The first non-empty line is the subject line in every cleanup mode but the Verbatim
+        // mode.
+        if subject.is_none() {
+            if cleanup_mode == CleanupMode::Verbatim {
+                // Set subject, doesn't matter what the content is. Even empty lines are considered
+                // subjects in Verbatim cleanup mode.
+                subject = Some(line.to_string());
+            } else if let Some(cleaned_line) = cleanup_line(&line, &cleanup_mode, &comment_char) {
+                if !cleaned_line.is_empty() {
+                    // Skip leading empty lines in every other cleanup mode than Verbatim.
+                    subject = Some(cleaned_line);
                 }
-                message_lines.push(line)
             }
+            // Skips this line if the cleanup mode is Strip and the line is a comment.
+            // See when the `cleanup_line` function returns `None`.
+            continue;
+        }
+
+        if let Some(cleaned_line) = cleanup_line(&line, &cleanup_mode, &comment_char) {
+            message_lines.push(cleaned_line)
         }
     }
     let used_subject = subject.unwrap_or_else(|| {
         debug!("Commit subject not present in message: {:?}", message);
-        ""
+        "".to_string()
     });
 
-    commit_for(
-        None,
-        None,
-        used_subject.to_string(),
-        message_lines,
-        has_changes,
-    )
+    commit_for(None, None, used_subject, message_lines, has_changes)
+}
+
+fn cleanup_line(line: &str, cleanup_mode: &CleanupMode, comment_char: &str) -> Option<String> {
+    match cleanup_mode {
+        CleanupMode::Default | CleanupMode::Strip => {
+            if line.starts_with(&comment_char) {
+                return None;
+            }
+            Some(line.trim_end().to_string())
+        }
+        CleanupMode::Whitespace | CleanupMode::Scissors => Some(line.trim_end().to_string()),
+        CleanupMode::Verbatim => Some(line.to_string()),
+    }
 }
 
 fn commit_for(
     sha: Option<String>,
     email: Option<String>,
     subject: String,
-    message: Vec<&str>,
+    message: Vec<String>,
     has_changes: bool,
 ) -> Commit {
     let mut commit = Commit::new(sha, email, subject, message.join("\n"), has_changes);
@@ -604,7 +625,63 @@ mod tests {
     #[test]
     fn test_parse_commit_hook_format_with_strip() {
         let commit = parse_commit_hook_format(
-            "This is a subject\n\
+            "This is a subject  \n\
+            \n\
+            This is the message body.  \n\
+            # This is a commented line.\n\
+            \n\
+            Another line.\n\
+            \n\
+            # Other things that are not part of the message.\n\
+            ",
+            CleanupMode::Strip,
+            "#".to_string(),
+            true,
+        );
+
+        assert_eq!(commit.long_sha, None);
+        assert_eq!(commit.short_sha, None);
+        assert_eq!(commit.email, None);
+        assert_eq!(commit.subject, "This is a subject");
+        assert_eq!(
+            commit.message,
+            "\nThis is the message body.\n\nAnother line.\n"
+        );
+    }
+
+    #[test]
+    fn test_parse_commit_hook_format_with_leading_empty_lines() {
+        let commit = parse_commit_hook_format(
+            "  \n\
+            This is a subject  \n\
+            \n\
+            This is the message body.  \n\
+            # This is a commented line.\n\
+            \n\
+            Another line.\n\
+            \n\
+            # Other things that are not part of the message.\n\
+            ",
+            CleanupMode::Strip,
+            "#".to_string(),
+            true,
+        );
+
+        assert_eq!(commit.long_sha, None);
+        assert_eq!(commit.short_sha, None);
+        assert_eq!(commit.email, None);
+        assert_eq!(commit.subject, "This is a subject");
+        assert_eq!(
+            commit.message,
+            "\nThis is the message body.\n\nAnother line.\n"
+        );
+    }
+
+    #[test]
+    fn test_parse_commit_hook_format_with_leading_comment_lines() {
+        let commit = parse_commit_hook_format(
+            "# This is a comment\n\
+            This is a subject  \n\
             \n\
             This is the message body.  \n\
             # This is a commented line.\n\
@@ -631,7 +708,7 @@ mod tests {
     #[test]
     fn test_parse_commit_hook_format_with_strip_custom_comment_char() {
         let commit = parse_commit_hook_format(
-            "This is a subject\n\
+            "This is a subject  \n\
             \n\
             This is the message body.  \n\
             - This is a commented line.\n\
@@ -658,9 +735,9 @@ mod tests {
     #[test]
     fn test_parse_commit_hook_format_with_scissors() {
         let commit = parse_commit_hook_format(
-            "This is a subject\n\
+            "This is a subject  \n\
             \n\
-            This is the message body.\n\
+            This is the message body.  \n\
             \n\
             This is line 2.\n\
             # ------------------------ >8 ------------------------\n\
@@ -681,10 +758,28 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_parse_commit_hook_format_with_scissors_empty_message() {
+        let commit = parse_commit_hook_format(
+            "# ------------------------ >8 ------------------------\n\
+            Other things that are not part of the message.\n\
+            ",
+            CleanupMode::Scissors,
+            "#".to_string(),
+            true,
+        );
+
+        assert_eq!(commit.long_sha, None);
+        assert_eq!(commit.short_sha, None);
+        assert_eq!(commit.email, None);
+        assert_eq!(commit.subject, "");
+        assert_eq!(commit.message, "");
+    }
+
     #[test]
     fn test_parse_commit_hook_format_with_verbatim() {
         let commit = parse_commit_hook_format(
-            "This is a subject\n\
+            "This is a subject  \n\
             \n\
             This is the message body.\n\
             # This is a comment\n\
@@ -710,10 +805,38 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_parse_commit_hook_format_with_verbatim_leading_empty_lines() {
+        let commit = parse_commit_hook_format(
+            "  \n\
+            This is the message body.\n\
+            # This is a comment\n\
+            # Other things that are not part of the message.\n\
+            Extra suprise!\
+            ",
+            CleanupMode::Verbatim,
+            "#".to_string(),
+            true,
+        );
+
+        assert_eq!(commit.long_sha, None);
+        assert_eq!(commit.short_sha, None);
+        assert_eq!(commit.email, None);
+        assert_eq!(commit.subject, "");
+        assert_eq!(
+            commit.message,
+            "This is the message body.\n\
+            # This is a comment\n\
+            # Other things that are not part of the message.\n\
+            Extra suprise!\
+            "
+        );
+    }
+
     #[test]
     fn test_parse_commit_hook_format_with_whitespace() {
         let commit = parse_commit_hook_format(
-            "This is a subject\n\
+            "This is a subject  \n\
             \n\
             This is the message body.  \n\
             \n\
@@ -742,4 +865,50 @@ mod tests {
             "
         );
     }
+
+    #[test]
+    fn test_parse_commit_hook_format_with_whitespace_leading_comment_lines() {
+        let commit = parse_commit_hook_format(
+            "# This is a comment\n\
+            This is a subject  \n\
+            \n\
+            This is the message body.",
+            CleanupMode::Whitespace,
+            "#".to_string(),
+            true,
+        );
+
+        assert_eq!(commit.long_sha, None);
+        assert_eq!(commit.short_sha, None);
+        assert_eq!(commit.email, None);
+        assert_eq!(commit.subject, "# This is a comment");
+        assert_eq!(
+            commit.message,
+            "This is a subject\n\nThis is the message body."
+        );
+    }
+
+    #[test]
+    fn test_parse_commit_hook_format_with_strip_and_scissor_line() {
+        // Even in default mode the scissor line is seen as the end of the message.
+        // This can happen when `git commit` is called with the `--verbose` flag.
+        let commit = parse_commit_hook_format(
+            "This is a subject  \n\
+            \n\
+            This is the message body.  \n\
+            # This is a comment before scissor line\n\
+            # ------------------------ >8 ------------------------\n\
+            # Other things that are not part of the message.\n\
+            List of file changes",
+            CleanupMode::Strip,
+            "#".to_string(),
+            true,
+        );
+
+        assert_eq!(commit.long_sha, None);
+        assert_eq!(commit.short_sha, None);
+        assert_eq!(commit.email, None);
+        assert_eq!(commit.subject, "This is a subject");
+        assert_eq!(commit.message, "\nThis is the message body.");
+    }
 }
